'use strict';

var app = require('*/cartridge/scripts/app');
var guard = require('*/cartridge/scripts/guard');

function placeOrder(){
    var placeOrderResult = app.getController('COPlaceOrder').Start();

    if (placeOrderResult.error) {
        if (placeOrderResult.redirectURL){
            response.redirect(placeOrderResult.redirectURL);
        } else {
            app.getController('COSummary').Start({
                PlaceOrderError: placeOrderResult.PlaceOrderError
            });
        }
    } else if (placeOrderResult.order_created) {
        app.getController('COSummary').ShowConfirmation(placeOrderResult.Order);
    }
}

function handlePayment() {
    var URLUtils = require('dw/web/URLUtils'),
        Logger = require('dw/system/Logger').getLogger('scalapay'),
        httpParams = request.httpParameterMap,
        orderToken = httpParams.isParameterSubmitted('orderToken') ? httpParams.orderToken.stringValue : '',
        status = httpParams.isParameterSubmitted('status') ? httpParams.status.stringValue : null;

    if (!session.privacy.scalapayAuthURL) {
        Logger.error('Scalapay payment authorization error. Error: Payment authorization URL missed');
        response.redirect(URLUtils.https('Cart-Show').toString());
    } else if (orderToken && status.toLowerCase() === 'success') {
        var Site = require('dw/system/Site'),
            isSummaryPageStepEnabled = Site.getCurrent().getCustomPreferenceValue('scalapayEnableSummaryPage'),
            scalapayHelper = require('*/cartridge/scripts/helpers/scalapayHelper');

        scalapayHelper.updatePaymentToken(orderToken);

        // check if summary page step is enabled. If disabled - Order will be placed immediately
        if (isSummaryPageStepEnabled){
            response.redirect(URLUtils.https('COSummary-Start').toString());
            return;
        } else {
            placeOrder();
        }
    } else {
        if (session.privacy.scalapayAuthURL) {
            delete session.privacy.scalapayAuthURL;
        }
        Logger.error('Scalapay payment authorization error. Error: Payment authorization rejected');
        response.redirect(URLUtils.https('COBilling-Start', 'error', 'scalapay.errorpayment.error.002').toString());
    }
    return;
}

function showWidget() {
    var scalaPayHelper = require('*/cartridge/scripts/helpers/scalapayHelper'),
        isScalaPayEnabled = scalaPayHelper.isEnabled(),
        httpParams = request.httpParameterMap,
        scalapayWidgetData;

    if (isScalaPayEnabled) {
        var scalaPayWidgetHelper = require('*/cartridge/scripts/helpers/scalaPayWidgetHelper');
        scalapayWidgetData = scalaPayWidgetHelper.getWidgetData({
            type: httpParams.isParameterSubmitted('type') ? httpParams.type.stringValue : '',
            pid: httpParams.isParameterSubmitted('pid') ? httpParams.pid.stringValue : ''
        });
    }
    app.getView({
        widgetSettings: scalapayWidgetData
    }).render('scalapay/scalapaywidget');
}

module.exports.ShowWidget = guard.ensure(['get', 'https'], showWidget);
module.exports.HandlePayment = guard.ensure(['get', 'https'], handlePayment);