'use strict';

function getProductPriceVal(apiProduct){
    var productUtils = require('*/cartridge/scripts/product/ProductUtils'),
        productPriceVal = 0;

    if (apiProduct){
        var productPricing = productUtils.getPricing(apiProduct);

        if (!productPricing.sale && !productPricing.standard){
            var productPriceModel = apiProduct.priceModel;
    
            if (productPriceModel){
                var minPrice = productPriceModel.minPrice;
    
                if (minPrice && minPrice.value > 0){
                    productPriceVal = minPrice.value;
                }
            }
        } else {
            productPriceVal = productPricing.sale ? productPricing.sale : productPricing.standard;
        }
    }
    return productPriceVal;
}

var ScalaPayWidgetHelper = {
    getWidgetData: function(parametersObj) {
        var widgetType = parametersObj.type,
            widgetData;

        if (widgetType) {
            if (widgetType === 'product' && parametersObj.pid) {
                widgetData = this.getProductEligibilityData(parametersObj.pid);
            } else if (widgetType === 'cart') {
                widgetData = this.getCartEligibilityData();
            }
        }
        return widgetData;
    },
    getCartEligibilityData: function(lineItemContainer) {
        if (!lineItemContainer) {
            var BasketMgr = require('dw/order/BasketMgr');
            lineItemContainer = BasketMgr.getCurrentOrNewBasket();
        }
        var scalapayUtils = require('*/cartridge/scripts/helpers/scalapayUtils'),
            cartWidgetData,
            priceTotal = scalapayUtils.getNonGiftCertificateAmount(lineItemContainer);

        if (priceTotal && priceTotal.value) {
            var scalaPayHelper = require('*/cartridge/scripts/helpers/scalapayHelper'),
                self = this,
                scalapaySettings = scalaPayHelper.getScalaPaySettings(priceTotal.value);

            if (scalapaySettings.isEligible) {
                cartWidgetData = {
                    display: scalapaySettings.isEligible,
                    priceVal: priceTotal.value,
                    minPriceVal: scalapaySettings.min,
                    maxPriceVal: scalapaySettings.max,
                    numberOfPayments: scalapaySettings.numberOfPayments,
                    renderingSettings: self.getWidgetRenderSettings('cart')
                };
            }
        }
        return cartWidgetData;
    },
    getProductEligibilityData: function(pid) {
        var apiProduct = require('dw/catalog/ProductMgr').getProduct(pid),
            productWidgetData,
            productPriceVal = getProductPriceVal(apiProduct);

        if (productPriceVal > 0) {
            var scalaPayHelper = require('*/cartridge/scripts/helpers/scalapayHelper'),
                isProductCategoryEligible = scalaPayHelper.isProductCategoryEligible(apiProduct);

            if (isProductCategoryEligible) {
                var productPrice = productPriceVal,
                    self = this,
                    scalapaySettings = scalaPayHelper.getScalaPaySettings(productPrice);

                if (scalapaySettings.isEligible) {
                    productWidgetData = {
                        display: scalapaySettings.isEligible,
                        priceVal: productPrice,
                        minPriceVal: scalapaySettings.min,
                        maxPriceVal: scalapaySettings.max,
                        numberOfPayments: scalapaySettings.numberOfPayments,
                        renderingSettings: self.getWidgetRenderSettings('product')
                    };
                }
            }
        }
        return productWidgetData;
    },
    getWidgetRenderSettings: function(type) {
        type = type || 'product';
        var currentSite = require('dw/system/Site').getCurrent(),
            defaultLocale = 'en',
            customClass = '',
            requestLocale = request.locale.split('_'),
            widgetLocale  = requestLocale.length > 1 ? requestLocale[0] : defaultLocale,
            redneringSettings = {
                locale: widgetLocale
            };

        if (type === 'product') {
            customClass = currentSite.getCustomPreferenceValue('scalaPayProductCustomClass') || '';
            redneringSettings.priceBoxSelector = (currentSite.getCustomPreferenceValue('scalaPayProductPriceBox') || '');
            redneringSettings.amountSelectorArray = (currentSite.getCustomPreferenceValue('scalaPayProductPriceSelector') || '');
            redneringSettings.showLogo = (currentSite.getCustomPreferenceValue('scalaPayProductShowLogo') || true);
            redneringSettings.textSize = (currentSite.getCustomPreferenceValue('scalaPayProductTextSize') || '100px');
            redneringSettings.logoSize = (currentSite.getCustomPreferenceValue('scalaPayProductLogoSize') || '100%');
            redneringSettings.logoColor = (currentSite.getCustomPreferenceValue('scalaPayProductLogoColor') || '#000000');
            redneringSettings.logoAlignment = (currentSite.getCustomPreferenceValue('scalaPayProductLogoAlignment') || '');
            redneringSettings.priceColor = (currentSite.getCustomPreferenceValue('scalaPayProductPriceColor') || '#145ad1');
        } else if (type === 'cart') {
            customClass = currentSite.getCustomPreferenceValue('scalaPayCartCustomClass') || '';
            redneringSettings.priceBoxSelector = (currentSite.getCustomPreferenceValue('scalaPayCartPriceBox') || '');
            redneringSettings.amountSelectorArray = (currentSite.getCustomPreferenceValue('scalaPayCartPriceSelector') || '');
            redneringSettings.showLogo = (currentSite.getCustomPreferenceValue('scalaPayCartShowLogo') || true);
            redneringSettings.textSize = (currentSite.getCustomPreferenceValue('scalaPayCartTextSize') || '100px');
            redneringSettings.logoSize = (currentSite.getCustomPreferenceValue('scalaPayCartLogoSize') || '100%');
            redneringSettings.logoColor = (currentSite.getCustomPreferenceValue('scalaPayCartLogoColor') || '#000000');
            redneringSettings.logoAlignment = (currentSite.getCustomPreferenceValue('scalaPayCartLogoAlignment') || '');
            redneringSettings.priceColor = (currentSite.getCustomPreferenceValue('scalaPayCartPriceColor') || '#145ad1');
        }
        redneringSettings.customClass = customClass.replace(/([.,])/g, '');
        return redneringSettings;

    }
};

module.exports = ScalaPayWidgetHelper;